@@ -29,7 +29,7 @@
 #include "tcpick.h"
 
 void
-print_conn_chain (conn_t * f)
+print_conn_chain (struct CONN * f)
 {
 	while (f) {
 		printf ("%x->",f);
@@ -45,7 +45,7 @@ print_conn_chain (conn_t * f)
 }
 
 int
-print_fragment_chain(struct fragment_t * f)
+print_fragment_chain(struct FRAGMENT * f)
 {
 	while (f) {
 		printf ("%x(%i,%i)->",f,f->off,f->len);
