@@ -9,8 +9,17 @@
  *
  */
 
+/* Do you wanna debug tcpick? Oh, thank you very much :^)
+ * Uncomment the following line to add 
+ * _really_ noisy debug messages
+ */
+
+//#define TCPICK_DEBUG 1
+
 #define TCPICK_NAME "tcpick"
 
+#define MAX_FILENAME_LENGHT 512
+
 #define MAXCONN 16384
 #define MAXMALLOC 16777216
 
@@ -41,3 +50,9 @@
 #ifndef MAX
 # define MAX(x,y) (((x)>(y))?(x):(y))
 #endif
+
+#ifndef TCPICK_DEBUG
+# define debug(fmt, ...) /* see msg.c for #ifdef TCPICK_DEBUG */
+#endif /* TCPICK_DEBUG */
+
+#define IP_SIZE 20
