@@ -12,19 +12,25 @@
 /* FIXME: it seems written by a ogre */
 extern struct ip *ippacket;
 extern struct tcphdr *tcppacket;
+extern struct udphdr *udppacket;
 extern u_char *payload;
 extern int payload_len;
-extern struct flags_t flags;
-extern int pcount;
+extern struct FLAGS flags;
+extern int count_packets;
+extern int count_conns;
+extern int count_opened;
 
 extern char * dev;
 extern char * readfile;
 extern char * filter;
 
-extern int dl_size;
+extern int iplen;
+extern int datalink_size;
 extern int ip_size;
-extern int data_trasl;
+extern int tcp_size;
+/* extern int data_trasl; */
 
-extern conn_t * first_conn;
-extern conn_t * last_conn;
+extern struct CONN * first_conn;
+extern struct CONN * last_conn;
 
+extern enum EXPIRED_FLAG expired_flag;
